@@ -1,11 +1,15 @@
 import logging
 import configparser
 
-logger = logging.getLogger('root')
+logger = logging.getLogger("root")
 
-FILENAME = "config.ini"
+FILENAME = ".stapy.ini"
 
 class Config:
+    """
+    This class allows to store and load settings that are relevant for stapy
+    Therefore one does not need to pass this arguments each time stapy is used
+    """
 
     def __init__(self, filename=None):
         self.filename = filename
@@ -18,7 +22,7 @@ class Config:
         self.config.read(self.filename)
 
     def save(self):
-        with open(self.filename, 'w') as configfile:
+        with open(self.filename, "w") as configfile:
             self.config.write(configfile)
 
     def get(self, arg):
